From 04035503e8922e7be597aae84b1ce29f2995ae23 Mon Sep 17 00:00:00 2001
From: Peter Wortmann <none@none>
Date: Mon, 15 Aug 2011 09:25:37 +0000
Subject: [PATCH 03/10] Save more minimal players on remote clients

---
 src/game/player/C4Player.cpp |   18 ++++++++++++++++--
 1 files changed, 16 insertions(+), 2 deletions(-)

diff --git a/src/game/player/C4Player.cpp b/src/game/player/C4Player.cpp
index 7c42f31..ccfff23 100644
--- a/src/game/player/C4Player.cpp
+++ b/src/game/player/C4Player.cpp
@@ -394,8 +394,22 @@ bool C4Player::Save()
 	char szPath[_MAX_PATH + 1];
 	SCopy(Config.AtTempPath(C4CFN_TempPlayer), szPath, _MAX_PATH);
 	MakeTempFilename(szPath);
-	// so full hard (flgr stupid) disks won't corrupt any player files...
-	C4Group_CopyItem(Filename, szPath);
+	// For local players, we save over the old player file, as there might
+	// be all kinds of non-essential stuff in it. For non-local players, we
+	// just re-create it every time (it's temporary anyway).
+	if (LocalControl)
+	{
+		// But make sure to copy it first so full hard (flgr stupid) disks
+		// won't corrupt any player files...
+		C4Group_CopyItem(Filename, szPath);
+	}
+	else
+	{
+		// For non-local players, we can actually use the loaded definition
+		// list to strip out all non-existant definitions. This is only valid
+		// because we know the file to be temporary.
+		CrewInfoList.Strip(::Definitions);
+	}
 	// Open group
 	if (!hGroup.Open(szPath,true))
 		return false;
-- 
1.7.7.1

